// Copyright (c) 2015-present, salesforce.com, inc. All rights reserved
// Licensed under BSD 3-Clause - see LICENSE.txt or git.io/sfdc-license
const chalk = require('chalk');

const createApp = require('./server/app');
const createSocket = require('./server/socket');

const createEmitter = (io, server) => {
  // decided to keep abstraction between framework events and
  // our frontend despite its futility
  return event => {
    switch (event) {
      case 'ready':
        console.log(
          chalk.green(
            `Previewer available at: http://localhost:${
              server.address().port
            }/local/preview`
          )
        );
        break;
      case 'bundle':
        return io.emit('setState', { type: 'bundleChanged' });
      case 'styles':
        return io.emit('setState', { type: 'cssChanged' });
    }
  };
};

module.exports = args => {
  const app = createApp(args);
  return {
    listen: (port, ready) => {
      const server = app.listen(port, () => {
        const io = createSocket(server);
        const emit = createEmitter(io, server);
        ready({ server, emit });
      });
    }
  };
};
